@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# Copyright (c) 2016-2025 Sullivan Beck. All rights reserved.
+# Copyright (c) 2016-2026 Sullivan Beck. All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -34,7 +34,7 @@ rename zu NewName alpha-2 => 1
 
 2code French => fr
 
-2code Greek => el
+2code 'Modern Greek (1453-)' => el
 
 2code Japanese => ja
 
